summaryrefslogtreecommitdiff
path: root/src/sock/sock.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/sock/sock.h')
-rwxr-xr-xsrc/sock/sock.h96
1 files changed, 59 insertions, 37 deletions
diff --git a/src/sock/sock.h b/src/sock/sock.h
index db01a49..264d9d1 100755
--- a/src/sock/sock.h
+++ b/src/sock/sock.h
@@ -10,62 +10,84 @@
#include <netinet/in.h>
#include <netdb.h>
-#include "../thrd/pool.h"
#include "../reqp.h"
#include "../chat/user.h"
+#include "../thrd/pool.h"
+#include "../maps/shashmap.h"
+
#ifdef LOGGING
#include "../logd.h"
#endif
-#include "../maps/hashmap.h"
-
using namespace std;
-class sock
+class sock : public shashmap
+ < string, uint32_t, self_hash<uint32_t>, equals_allocator<uint32_t> >
{
-private:
- // total number of server requests.
- unsigned long long i_req;
-
- bool b_run; // true while socket manager is running.
- reqp *req_parser; // parses the http requests from clients.
- pool *thrd_pool; // the thread pool.
+protected:
#ifdef LOGGING
- logd *log_daemon; // the log daemon
-#endif
- char *c_buffer; // char buffer!
- int i_threads; // total amount of threads inside the thread pool.
-
- pthread_mutex_t mut_hits;
-public:
- // creates a server socket.
- int make_server_socket( int i_port );
+ logd *log_daemon; // the log daemon
+#endif
- // small inline methods:
- bool get_run() const
- {
- return b_run;
- }
+ int i_server_sock;
+ int i_server_port;
- bool set_run( bool b_run )
- {
- this->b_run = b_run;
- }
+ // total number of server requests.
+ unsigned long long i_req;
+ bool b_run; // true while socket manager is running.
+ reqp *req_parser; // parses the http requests from clients.
+ char *c_buffer; // char buffer!
+ pthread_mutex_t mut_hits;
- sock( );
- ~sock( );
+ static string inet_ntoa_callback(void* p_void);
- int read_write( int* p_sock );
- int start();
+public:
+ // creates a server socket.
+ int read_http(socketcontainer *p_sock, char *c_zbuf, int i_buflen, int &i_payloadoffset);
+ string read_http_line(socketcontainer *p_sock);
+
+ // small inline methods:
+ bool get_server_() const
+ {
+ return b_run;
+ }
+ // small inline methods:
+ bool get_run() const
+ {
+ return b_run;
+ }
+ bool set_run( bool b_run )
+ {
+ this->b_run = b_run;
+ }
+
+ sock();
+
+ int read_write( socketcontainer* p_sock );
+
+ int start();
+ void clean_ipcache();
+
+ // the chat stream there all the chat messages will sent through.
+ void chat_stream( socketcontainer* p_sock, user* p_user, map<string,string> &map_params ); //<<
+ virtual int _send(socketcontainer *p_sock, const char *sz, int len);
+ virtual int _read(socketcontainer *p_sock, char *sz, int len);
+ virtual int _close(socketcontainer *p_sock);
+ virtual void _main_loop_init();
+#ifdef OPENSSL
+
+ virtual bool _main_loop_do_ssl_stuff(int& i_new_sock);
+#endif
- // the chat stream there all the chat messages will sent through.
- static void chat_stream( int i_sock, user* p_user, hashmap<string> &map_params ); //<<
+ virtual socketcontainer* _create_container(int& i_sock);
+ virtual int _make_server_socket(int i_port);
#ifdef NCURSES
- void print_hits();
+ void print_server_port();
+ void print_hits();
#endif
-};
+};
#endif